==> qtjambi-positioning-debuginfo-macos-6.5.3.jar: sources/QtJambiPositioning/QNmeaSatelliteInfoSource_shell.h <==
#ifndef QNMEASATELLITEINFOSOURCE_SHELL_H
#define QNMEASATELLITEINFOSOURCE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtPositioning/qnmeasatelliteinfosource.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qbytearrayview.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qiodevice.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtPositioning/qgeosatelliteinfo.h>
#include <QtPositioning/qgeosatelliteinfosource.h>
#include <QtJambi/RegistryAPI>


class QNmeaSatelliteInfoSource_shell : public QNmeaSatelliteInfoSource, public QtJambiShellInterface
{
public:
    QNmeaSatelliteInfoSource_shell(QNmeaSatelliteInfoSource::UpdateMode mode0, QObject* parent1 = nullptr);
    ~QNmeaSatelliteInfoSource_shell() override;

    QVariant backendProperty(const QString& name0) const override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    QGeoSatelliteInfoSource::Error error() const override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    int minimumUpdateInterval() const override;
    QNmeaSatelliteInfoSource::SatelliteInfoParseStatus parseSatelliteInfoFromNmea(const char* data0, int size1, QList<QGeoSatelliteInfo>& infos2, QGeoSatelliteInfo::SatelliteSystem& system3) override;
    QGeoSatelliteInfo::SatelliteSystem parseSatellitesInUseFromNmea(const char* data0, int size1, QList<int>& pnrsInUse2) override;
    void requestUpdate(int timeout0) override;
    bool setBackendProperty(const QString& name0, const QVariant& value1) override;
    void setUpdateInterval(int msec0) override;
    void startUpdates() override;
    void stopUpdates() override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QNmeaSatelliteInfoSource_access : public QNmeaSatelliteInfoSource
{
    jint __qt_parseSatelliteInfoFromNmea_QByteArrayView_ref_QList_ref_QGeoSatelliteInfo_SatelliteSystem(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID data0, jobject infos1, jobjectArray system2);
    jint __qt_parseSatellitesInUseFromNmea_QByteArrayView_ref_QList(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID data0, jobject pnrsInUse1);
    void __qt_setError_QGeoSatelliteInfoSource_Error(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint satelliteError0);
    jobject __qt_backendProperty_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0) const;
    jint __qt_error(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_minimumUpdateInterval(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_parseSatelliteInfoFromNmea_const_char_ptr_int_ref_QList_ref_QGeoSatelliteInfo_SatelliteSystem(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jbyteArray data0, jobject infos2, jobjectArray system3);
    jint __qt_parseSatellitesInUseFromNmea_const_char_ptr_int_ref_QList(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jbyteArray data0, jobject pnrsInUse2);
    void __qt_requestUpdate_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint timeout0);
    jboolean __qt_setBackendProperty_cref_QString_cref_QVariant(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0, jobject value1);
    void __qt_setUpdateInterval_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint msec0);
    void __qt_startUpdates(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_stopUpdates(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    static inline const std::type_info& __registerEnumTypeInfo_SatelliteInfoParseStatus() {
        return RegistryAPI::registerEnumTypeInfo<QNmeaSatelliteInfoSource::SatelliteInfoParseStatus>("QNmeaSatelliteInfoSource::SatelliteInfoParseStatus", "io/qt/positioning/QNmeaSatelliteInfoSource$SatelliteInfoParseStatus");
    }
};

#endif // QNMEASATELLITEINFOSOURCE_SHELL_H

==> qtjambi-positioning-debuginfo-macos-6.5.4.jar: sources/QtJambiPositioning/QNmeaSatelliteInfoSource_shell.h <==
#ifndef QNMEASATELLITEINFOSOURCE_SHELL_H
#define QNMEASATELLITEINFOSOURCE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtPositioning/qnmeasatelliteinfosource.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qbytearrayview.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qiodevice.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtPositioning/qgeosatelliteinfo.h>
#include <QtPositioning/qgeosatelliteinfosource.h>
#include <QtJambi/RegistryAPI>


class QNmeaSatelliteInfoSource_shell : public QNmeaSatelliteInfoSource, public QtJambiShellInterface
{
public:
    QNmeaSatelliteInfoSource_shell(QNmeaSatelliteInfoSource::UpdateMode mode0, QObject* parent1 = nullptr);
    ~QNmeaSatelliteInfoSource_shell() override;

    QVariant backendProperty(const QString& name0) const override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    QGeoSatelliteInfoSource::Error error() const override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    int minimumUpdateInterval() const override;
    QNmeaSatelliteInfoSource::SatelliteInfoParseStatus parseSatelliteInfoFromNmea(const char* data0, int size1, QList<QGeoSatelliteInfo>& infos2, QGeoSatelliteInfo::SatelliteSystem& system3) override;
    QGeoSatelliteInfo::SatelliteSystem parseSatellitesInUseFromNmea(const char* data0, int size1, QList<int>& pnrsInUse2) override;
    void requestUpdate(int timeout0) override;
    bool setBackendProperty(const QString& name0, const QVariant& value1) override;
    void setUpdateInterval(int msec0) override;
    void startUpdates() override;
    void stopUpdates() override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QNmeaSatelliteInfoSource_access : public QNmeaSatelliteInfoSource
{
    jint __qt_parseSatelliteInfoFromNmea_QByteArrayView_ref_QList_ref_QGeoSatelliteInfo_SatelliteSystem(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID data0, jobject infos1, jobjectArray system2);
    jint __qt_parseSatellitesInUseFromNmea_QByteArrayView_ref_QList(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID data0, jobject pnrsInUse1);
    void __qt_setError_QGeoSatelliteInfoSource_Error(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint satelliteError0);
    jobject __qt_backendProperty_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0) const;
    jint __qt_error(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_minimumUpdateInterval(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_parseSatelliteInfoFromNmea_const_char_ptr_int_ref_QList_ref_QGeoSatelliteInfo_SatelliteSystem(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject data0, jobject infos2, jobjectArray system3);
    jint __qt_parseSatellitesInUseFromNmea_const_char_ptr_int_ref_QList(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject data0, jobject pnrsInUse2);
    void __qt_requestUpdate_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint timeout0);
    jboolean __qt_setBackendProperty_cref_QString_cref_QVariant(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0, jobject value1);
    void __qt_setUpdateInterval_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint msec0);
    void __qt_startUpdates(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_stopUpdates(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    static inline const std::type_info& __registerEnumTypeInfo_SatelliteInfoParseStatus() {
        return RegistryAPI::registerEnumTypeInfo<QNmeaSatelliteInfoSource::SatelliteInfoParseStatus>("QNmeaSatelliteInfoSource::SatelliteInfoParseStatus", "io/qt/positioning/QNmeaSatelliteInfoSource$SatelliteInfoParseStatus");
    }
};

#endif // QNMEASATELLITEINFOSOURCE_SHELL_H
